@@ -1,5 +1,8 @@
+"""Package for working with Cypress Creek Renewables Dashboard process
+"""
+
 from ccrenew.dashboard.session import DashboardSession
-from ccrenew.dashboard.plotting.plots import Plotter
+from ccrenew.dashboard.project import Project
 from ccrenew.dashboard.utils.dashboard_utils import run_bluesky
 from ccrenew.dashboard.utils.project_neighbors import (
     find_nearby_projects,
