@@ -189,10 +189,11 @@ class DashboardSession(object):
 
         Args:
             project_name (str, Project, or list): The name of the project to process.
-            reprocess (bool, optional): Whether to reprocess the data. This option will likely\
-            be uncommon as any changes to a project's config file or powertrack file will\
-            automatically reprocess that data. This could be used if any changes are made\
-            outside of the config/powertrack file or a change is made to a neighbor. Defaults to False.
+            reprocess (bool, optional): Whether to reprocess the data. This option will likely
+                be uncommon as any changes to a project's config file or powertrack file will
+                automatically reprocess that data. This could be used if any changes are made
+                outside of the config/powertrack file or a change is made to a neighbor.
+                Defaults to False.
         """
         if isinstance(project_name, list):
             self.process_projects(project_name, reprocess)
@@ -236,11 +237,11 @@ class DashboardSession(object):
     
     
     def process_projects(self, project_list, reprocess=False):
-        """Calls `process_project` for each project in a list
+        """Calls :meth:`process_project` for each project in a list
 
         Args:
-            project_list (list, str, or Project): List of project names of `Project` objects to process.
-            reprocess (bool, optional): See `process_project`. Defaults to False.
+            project_list (list, str, or Project): List of project names of :class:`~ccrenew.dashboard.project.Project` objects to process.
+            reprocess (bool, optional): See :meth:`process_project`. Defaults to False.
         """
         if isinstance(project_list, (str, unicode, Project)):
             project_name = project_list
@@ -254,7 +255,7 @@ class DashboardSession(object):
     
 
     def process_all_projects(self):
-        """Processes all projects in the `project_list` for the `DashboardSession` instance
+        """Processes all projects in the :attr:`~project_list` for the :class:`~DashboardSession` instance
         """
         # FIXME: add data cutoff date in here in case you want to change that in the middle of a session
         # FIXME: Same with process project object below
@@ -263,6 +264,16 @@ class DashboardSession(object):
 
 
     def pickle_project(self, project_name, year=None):
+        """Saves the project to a serialized pickle in the :attr:`~ccrenew.dashboard.project.Project.project_directory`
+        for the :class:`~ccrenew.dashboard.project.Project`.
+
+        Args:
+            project_name (str, Project, or list): The name of the project to pickle.
+            year (int, optional): Year to save the pickle. Defaults to None.
+
+        Raises:
+            TypeError: if the wrong type is supplied to :attr:`~ccrenew.dashboard.project.Project.project_directory`.
+        """
         if isinstance(project_name, list):
             self.pickle_projects(project_name, year)
         elif isinstance(project_name, (str, Project)):
@@ -273,7 +284,9 @@ class DashboardSession(object):
 
 
     def pickle_projects(self, project_list, year=None):
-        if isinstance(project_list, str):
+        """Alias for :meth:`pickle_project`.
+        """
+        if isinstance(project_list, (str, Project)):
             project_name = project_list
             self.pickle_project(project_name)
             return
@@ -285,10 +298,10 @@ class DashboardSession(object):
 
 
     def load_pickle(self, project_name, year=None):
-        """Loads a pickled object from file
+        """Loads a pickled object from file.
 
         Args:
-            project_name (str): The name of a project to load
+            project_name (str): The name of a project to load.
             year (int, optional): Year to load for the pickle. Defaults to current year.
         """
         if not year:
@@ -320,6 +333,15 @@ class DashboardSession(object):
         return project
 
     def __update_project_filepaths(self, project):
+        """Sets filepaths for config file, Powertrack file, and Pickle Jar
+
+        Args:
+            project (Project): A :class:`~ccrenew.dashboard.project.Project`
+
+        Returns:
+            Project: a `~ccrenew.dashboard.project.Project` with updated
+                filepaths
+        """
         
         # Update filepath references for the project
         project.dashboard_dir = self.dashboard_dir
@@ -462,30 +484,61 @@ class DashboardSession(object):
         """Draws plots for the given project
 
         Args:
-            project_name (str, Project, or list): A project to draw plots on for analysis.
-            plot_order (list or str, optional): A list of plots to draw. This can be
-                any number of plots from one to all plots. Defaults to all plots in the below order.
-            Default Order:
-            
-                * xplot_met_poa: Crossplot of meter & POA data.
-                * `xplot_temp`: Crossplot of meter & POA, colored by Tamb.
-                * `temps`: Tcell temperature comparison.
-                * `inv`: Inverters.
-                * `pr`: Hourly PR plot.
-                * `8760`: Measured vs 8760 comparison.
-                * `weather`: Weather sensors.
-                * `met_corr`: Meter corrections.
-                * `met_corr_dif`: Meter correction dif.
-                * `poas`: POA sensors.
-                * `met_poa`: Meter & POA avg.
-                * `ghi`: GHI sensors.
-                * `irrad`: POA & GHI sensors.
-                * `tz`: Timezone check.
-                * `losses`: Losses by type.
-                * `poa_corr`: POA correlation check.
+            project_name (str, Project, or list): A project or list of projects
+                to draw plots on for analysis. If a list is supplied it will plot
+                the projects one-by-one. The user must press a button in the final
+                plot of each project to move on to the next one.
+            plot_order (list or str, optional): A list of plots to draw. This can
+                be any number of plots from one to all plots. Defaults to all plots in the below order.
+
+        **Default Plot Order**
+
+                +---------------------------+-----------------------------------------------------------+
+                | Plot Alias                | Plot Description                                          |
+                +===========================+===========================================================+
+                |    ``xplot_pwr_poa``      |    Crossplot of power meter & POA data                    |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``xplot_temp``         |    Crossplot of power meter & POA data, colored by Tamb   |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``temps``              |    Tcell temperature comparison                           |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``inv``                |    Inverters                                              |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``pr``                 |    Hourly Performance Ratio                               |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``8760``               |    Meter Corrected vs 8760                                |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``weather``            |    Weather sensors                                        |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``mtr_correct``        |    Meter corrections                                      |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``mtr_dif``            |    Meter correction dif                                   |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``poas``               |    POA sensors                                            |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``pwr_poa``            |    Power meter & POA Avg timeseries plot                  |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``ghi``                |    GHI sensors                                            |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``irrad``              |    POA & GHI sensors                                      |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``tz``                 |    Timezone check                                         |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``losses``             |    Losses  by type                                        |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``poa_corr``           |    POA correlation check                                  |
+                +---------------------------+-----------------------------------------------------------+
+
+        **Other Optional Plots**
+
+                +---------------------------+-----------------------------------------------------------+
+                | Plot Alias                | Plot Description                                          |
+                +===========================+===========================================================+
+                |    ``meters``             |    Original & corrected power and cumulative meters       |
+                +---------------------------+-----------------------------------------------------------+
+                |    ``native``             |    Native POA/GHI/Tamb/Tmod/Wind sensor subplots          |
+                +---------------------------+-----------------------------------------------------------+
 
-            **kwargs: See below.
-        
         Keyword Args:
             mth (int): The month to show on the Power vs POA crossplot.
             open_folder (bool): Option to open the project's folder on the filesystem.
